@@ -1,21 +1,9 @@
-/*  This file is part of the KDE libraries
-    Copyright (C) 1999 Waldo Bastian (bastian@kde.org)
-    Copyright 2012 David Faure <faure+bluesystems@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 1999 Waldo Bastian <bastian@kde.org>
+    SPDX-FileCopyrightText: 2012 David Faure <faure+bluesystems@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; version 2
-    of the License.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #include "kmessagebox.h"
@@ -24,16 +12,15 @@
 #include <QPointer>
 #include <QCheckBox>
 #include <QDialog>
-#include <QDialogButtonBox>
 #include <QLabel>
 #include <QLayout>
 #include <QListWidget>
 #include <QPushButton>
-#include <QDesktopWidget>
 #include <QScrollArea>
 #include <QScrollBar>
 #include <QTextBrowser>
 #include <QWindow>
+#include <QScreen>
 
 #include <qapplication.h>
 #if 0
@@ -200,8 +187,9 @@ QDialogButtonBox::StandardButton createKMessageBox(QDialog *dialog, QDialogButto
 
     QWidget *mainWidget = new QWidget(dialog);
     QVBoxLayout *mainLayout = new QVBoxLayout(mainWidget);
-    const int spacingHint = mainWidget->style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing);
-    mainLayout->setSpacing(spacingHint * 2); // provide extra spacing
+    const int verticalSpacing = mainWidget->style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing);
+    const int horizontalSpacing = mainWidget->style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing);
+    mainLayout->setSpacing(verticalSpacing * 2); // provide extra spacing
     mainLayout->setContentsMargins(0, 0, 0, 0);
     buttons->setParent(dialog);
 
@@ -224,7 +212,7 @@ QDialogButtonBox::StandardButton createKMessageBox(QDialog *dialog, QDialogButto
     iconLayout->addStretch(5);
 
     hLayout->addLayout(iconLayout, 0);
-    hLayout->addSpacing(spacingHint);
+    hLayout->addSpacing(horizontalSpacing);
 
     QLabel *messageLabel = new QLabel(text, mainWidget);
     messageLabel->setOpenExternalLinks(options & KMessageBox::AllowLink);
@@ -234,7 +222,7 @@ QDialogButtonBox::StandardButton createKMessageBox(QDialog *dialog, QDialogButto
     }
     messageLabel->setTextInteractionFlags(flags);
 
-    QRect desktop = QApplication::desktop()->screenGeometry(dialog);
+    QRect desktop = dialog->screen()->geometry();
     bool usingSqueezedTextLabel = false;
     if (messageLabel->sizeHint().width() > desktop.width() * 0.5) {
         // enable automatic wrapping of messages which are longer than 50% of screen width
@@ -304,13 +292,12 @@ QDialogButtonBox::StandardButton createKMessageBox(QDialog *dialog, QDialogButto
         }
     }
 
-    QVBoxLayout *topLayout = new QVBoxLayout;
-    dialog->setLayout(topLayout);
+    QVBoxLayout *topLayout = new QVBoxLayout(dialog);
     topLayout->addWidget(mainWidget);
 
     if (!details.isEmpty()) {
         QHBoxLayout *detailsHLayout = new QHBoxLayout();
-        detailsHLayout->addSpacing(2 * spacingHint + iconLayout->sizeHint().width());
+        detailsHLayout->addSpacing(2 * horizontalSpacing + iconLayout->sizeHint().width());
         KCollapsibleGroupBox *detailsGroup = new KCollapsibleGroupBox();
         detailsGroup->setTitle(QApplication::translate("KMessageBox", "Details"));
         QVBoxLayout *detailsLayout = new QVBoxLayout(detailsGroup);
