@@ -1,23 +1,9 @@
 /*
     This file is part of the KDE Libraries
+    SPDX-FileCopyrightText: 2006 Tobias Koenig <tokoe@kde.org>
+    SPDX-FileCopyrightText: 2007 Rafael Fernández López <ereslibre@kde.org>
 
-    Copyright (C) 2006 Tobias Koenig (tokoe@kde.org)
-    Copyright (C) 2007 Rafael Fernández López (ereslibre@kde.org)
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB. If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kpageview_p.h"
@@ -34,9 +20,7 @@
 
 using namespace KDEPrivate;
 
-/**
- * KPagePlainView
- */
+// KPagePlainView
 
 KPagePlainView::KPagePlainView(QWidget *parent)
     : QAbstractItemView(parent)
@@ -87,9 +71,7 @@ QRegion KPagePlainView::visualRegionForSelection(const QItemSelection &) const
     return QRegion();
 }
 
-/**
- * KPageListView
- */
+// KPageListView
 
 KPageListView::KPageListView(QWidget *parent)
     : QListView(parent)
@@ -146,9 +128,7 @@ void KPageListView::updateWidth()
     setFixedWidth(sizeHintForColumn(0) + verticalScrollBar()->sizeHint().width() + 5);
 }
 
-/**
- * KPageTreeView
- */
+// KPageTreeView
 
 KPageTreeView::KPageTreeView(QWidget *parent)
     : QTreeView(parent)
@@ -197,9 +177,7 @@ void KPageTreeView::expandItems(const QModelIndex &index)
     }
 }
 
-/**
- * KPageTabbedView
- */
+// KPageTabbedView
 
 KPageTabbedView::KPageTabbedView(QWidget *parent)
     : QAbstractItemView(parent)
@@ -335,7 +313,6 @@ void KPageTabbedView::layoutChanged()
         if (page) {
             QWidget *widget = new QWidget(this);
             QVBoxLayout *layout = new QVBoxLayout(widget);
-            widget->setLayout(layout);
             layout->addWidget(page);
             page->setVisible(true);
             mTabWidget->addTab(widget, icon, title);
@@ -364,9 +341,7 @@ void KPageTabbedView::dataChanged(const QModelIndex &index, const QModelIndex &,
     }
 }
 
-/**
- * KPageListViewDelegate
- */
+// KPageListViewDelegate
 
 KPageListViewDelegate::KPageListViewDelegate(QObject *parent)
     : QAbstractItemDelegate(parent)
@@ -463,9 +438,7 @@ QSize KPageListViewDelegate::sizeHint(const QStyleOptionViewItem &option, const
     int hp = pixmap.height() / pixmap.devicePixelRatio();
 
     if (hp == 0) {
-        /**
-         * No pixmap loaded yet, we'll use the default icon size in this case.
-         */
+        // No pixmap loaded yet, we'll use the default icon size in this case.
         hp = iconSize;
         wp = iconSize;
     }
@@ -503,9 +476,7 @@ void KPageListViewDelegate::drawFocus(QPainter *painter, const QStyleOptionViewI
     }
 }
 
-/**
- * KPageListViewProxy
- */
+// KPageListViewProxy
 
 KPageListViewProxy::KPageListViewProxy(QObject *parent)
     : QAbstractProxyModel(parent)
@@ -594,7 +565,7 @@ void KPageListViewProxy::rebuildMap()
         qCDebug(KWidgetsAddonsLog, "%d:0 -> %d:%d", i, mList[ i ].row(), mList[ i ].column());
     }
 
-    emit layoutChanged();
+    Q_EMIT layoutChanged();
 }
 
 void KPageListViewProxy::addMapEntry(const QModelIndex &index)
