@@ -9,13 +9,12 @@
 
 #include "kpopupframe.h"
 
-#include <QDesktopWidget>
 #include <QEventLoop>
 #include <QGuiApplication>
 #include <QKeyEvent>
 #include <QScreen>
 
-class Q_DECL_HIDDEN KPopupFrame::KPopupFramePrivate
+class KPopupFramePrivate
 {
 public:
     KPopupFramePrivate(KPopupFrame *q);
@@ -38,7 +37,7 @@ public:
     OutsideClickCatcher *outsideClickCatcher;
 };
 
-class KPopupFrame::KPopupFramePrivate::OutsideClickCatcher
+class KPopupFramePrivate::OutsideClickCatcher
     : public QObject
 {
     Q_OBJECT
@@ -64,13 +63,13 @@ public:
         if (event->type() == QEvent::Hide && m_popup) {
             // do not set d->result here, because the popup
             // hides itself after leaving the event loop.
-            emit m_popup->leaveModality();
+            Q_EMIT m_popup->leaveModality();
         }
         return false;
     }
 };
 
-KPopupFrame::KPopupFramePrivate::KPopupFramePrivate(KPopupFrame *q):
+KPopupFramePrivate::KPopupFramePrivate(KPopupFrame *q):
     q(q),
     result(0),   // rejected
     main(nullptr),
@@ -79,7 +78,7 @@ KPopupFrame::KPopupFramePrivate::KPopupFramePrivate(KPopupFrame *q):
     outsideClickCatcher->setPopupFrame(q);
 }
 
-KPopupFrame::KPopupFramePrivate::~KPopupFramePrivate()
+KPopupFramePrivate::~KPopupFramePrivate()
 {
     delete outsideClickCatcher;
 }
@@ -91,16 +90,13 @@ KPopupFrame::KPopupFrame(QWidget *parent)
     setMidLineWidth(2);
 }
 
-KPopupFrame::~KPopupFrame()
-{
-    delete d;
-}
+KPopupFrame::~KPopupFrame() = default;
 
 void KPopupFrame::keyPressEvent(QKeyEvent *e)
 {
     if (e->key() == Qt::Key_Escape) {
         d->result = 0; // rejected
-        emit leaveModality();
+        Q_EMIT leaveModality();
         //qApp->exit_loop();
     }
 }
@@ -113,7 +109,7 @@ void KPopupFrame::hideEvent(QHideEvent *e)
 void KPopupFrame::close(int r)
 {
     d->result = r;
-    emit leaveModality();
+    Q_EMIT leaveModality();
     //qApp->exit_loop();
 }
 
