@@ -11,10 +11,10 @@
 #include <QMouseEvent>
 #include <QPalette>
 
-class Q_DECL_HIDDEN KUrlLabel::Private
+class KUrlLabelPrivate
 {
 public:
-    Private(const QString &_url, KUrlLabel *_parent)
+    KUrlLabelPrivate(const QString &_url, KUrlLabel *_parent)
         : parent(_parent),
           url(_url),
           tipText(url),
@@ -29,11 +29,7 @@ public:
           floatEnabled(false),
           timer(new QTimer(parent))
     {
-        connect(timer, &QTimer::timeout, parent, [this]() { updateColor(); });
-    }
-
-    ~Private()
-    {
+        QObject::connect(timer, &QTimer::timeout, parent, [this]() { updateColor(); });
     }
 
     void updateColor()
@@ -74,7 +70,7 @@ public:
 
 KUrlLabel::KUrlLabel(const QString &url, const QString &text, QWidget *parent)
     : QLabel(!text.isNull() ? text : url, parent),
-      d(new Private(url, this))
+      d(new KUrlLabelPrivate(url, this))
 {
     setFont(font());
     setCursor(QCursor(Qt::PointingHandCursor));
@@ -83,17 +79,14 @@ KUrlLabel::KUrlLabel(const QString &url, const QString &text, QWidget *parent)
 
 KUrlLabel::KUrlLabel(QWidget *parent)
     : QLabel(parent),
-      d(new Private(QString(), this))
+      d(new KUrlLabelPrivate(QString(), this))
 {
     setFont(font());
     setCursor(QCursor(Qt::PointingHandCursor));
     d->setLinkColor(d->linkColor);
 }
 
-KUrlLabel::~KUrlLabel()
-{
-    delete d;
-}
+KUrlLabel::~KUrlLabel() = default;
 
 void KUrlLabel::mouseReleaseEvent(QMouseEvent *event)
 {
@@ -104,23 +97,23 @@ void KUrlLabel::mouseReleaseEvent(QMouseEvent *event)
 
     switch (event->button()) {
     case Qt::LeftButton:
-        emit leftClickedUrl();
+        Q_EMIT leftClickedUrl();
 #if KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(5, 65)
-        emit leftClickedUrl(d->url);
+        Q_EMIT leftClickedUrl(d->url);
 #endif
         break;
 
     case Qt::MiddleButton:
-        emit middleClickedUrl();
+        Q_EMIT middleClickedUrl();
 #if KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(5, 65)
-        emit middleClickedUrl(d->url);
+        Q_EMIT middleClickedUrl(d->url);
 #endif
         break;
 
     case Qt::RightButton:
-        emit rightClickedUrl();
+        Q_EMIT rightClickedUrl();
 #if KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(5, 65)
-        emit rightClickedUrl(d->url);
+        Q_EMIT rightClickedUrl(d->url);
 #endif
         break;
 
@@ -296,9 +289,9 @@ void KUrlLabel::enterEvent(QEvent *event)
             setUnderline(true);
         }
     }
-    emit enteredUrl();
+    Q_EMIT enteredUrl();
 #if KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(5, 65)
-    emit enteredUrl(d->url);
+    Q_EMIT enteredUrl(d->url);
 #endif
 }
 
@@ -320,9 +313,9 @@ void KUrlLabel::leaveEvent(QEvent *event)
     }
 
     setUnderline(d->realUnderlined);
-    emit leftUrl();
+    Q_EMIT leftUrl();
 #if KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(5, 65)
-    emit leftUrl(d->url);
+    Q_EMIT leftUrl(d->url);
 #endif
 }
 
